@@ -8,5 +8,7 @@ void getRandVect(float * vect, size_t n);
 void printVect(int n, const float * vect, const char * msg);
 void printMat(int rows, int cols, const float * mat, const char * msg);
 void checkCudaError(const char * msg);
+int hasCudaError(const char * msg);
 float * getMatFromFile(int rows, int cols, const char * fn);
 void checkCublasError(const char * msg);
+int hasCublasError(const char * msg);
